.check-menu-dropdown{position:relative;width:20px;left:-2px}.check-menu-dropdown .g-job-check-menu-button{padding:2px 1px 0 2px}.check-menu-dropdown .g-job-check-menu-button i{position:relative;top:-3px}.g-imports-list-table{width:100%;hyphenate-character:""}.g-imports-list-table th{border-bottom:1px solid #a5a5a5;padding:0 10px}.g-imports-list-table tbody>tr{transition:background .1s linear;border-bottom:1px solid #d7d7d7}.g-imports-list-table tbody>tr td{padding:3px 5px}.g-imports-list-table tbody>tr:hover{background-color:#ddd}.g-imports-list-table tbody>tr.g-highlight{background-color:#f1db74}.g-imports-list-table tbody>tr button+button{margin-left:5px}.g-imports-list-table tbody>tr .g-imports-buttons{display:flex;padding-right:1em}.g-job-list-header{padding-bottom:10px}#g-job-checkbox-menu{display:inline}a.g-job-checkbox-menu-link{display:inline-block;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;color:#333}.g-job-filter-container{margin-top:7px}.g-job-filter-container>div{float:left;margin-right:10px}.g-job-filter-container>.checkbox{margin:0 0 0 10px}.g-job-filter-container .dropdown .dropdown-menu ul{list-style-type:none;padding:0;margin:0}.g-job-filter-container .dropdown .checkbox{margin:8px}.g-job-filter-container .dropdown .checkbox.g-job-checkall{padding-bottom:8px;border-bottom:1px solid #ddd}.g-page-size-container{float:right;margin-top:7px}.g-page-size-container>span{margin-right:10px}ul.g-jobs{margin:10px 0}.g-jobs-graph{height:calc(100vh - 230px);overflow-y:hidden;overflow-x:auto}.g-no-job-record{text-align:center}.g-job-worker-task-info{margin-top:10px}.it-controls{margin-bottom:10px}
